@@ -34,7 +34,7 @@ import System.Process (readProcessWithExitCode)
 import System.Time (ClockTime, getClockTime, diffClockTimes, TimeDiff(TimeDiff))
 import Test.HUnit
 import Text.Printf
-#if __GLASGOW_HASKELL__ >= 706
+#if MIN_VERSION_directory(1,2,0)
 import System.Time (ClockTime(TOD))
 import Data.Time.Clock.POSIX (utcTimeToPOSIXSeconds)
 #endif
@@ -103,13 +103,12 @@ fileModificationTime :: FilePath -> IO ClockTime
 fileModificationTime f
     | null f = getClockTime
     | otherwise = (do
--- getModificationTime returned a ClockTime till GHC 7.6 (directory 1.2), now it's UTCTime
-#if __GLASGOW_HASKELL__ < 706
-        clo <- getModificationTime f
-#else
+#if MIN_VERSION_directory(1,2,0)
         utc <- getModificationTime f
         let nom = utcTimeToPOSIXSeconds utc
         let clo = TOD (read $ takeWhile (`elem` "0123456789") $ show nom) 0 -- XXX read
+#else
+        clo <- getModificationTime f
 #endif
         return clo
         )
@@ -142,7 +141,7 @@ openBrowserOn u = trybrowsers browsers u
 -- indicating whether we did anything.
 writeFileWithBackupIfChanged :: FilePath -> String -> IO Bool
 writeFileWithBackupIfChanged f t = do
-  s <- readFile f
+  s <- readFile' f
   if t == s then return False
             else backUpFile f >> writeFile f t >> return True
 
@@ -152,7 +151,7 @@ writeFileWithBackup :: FilePath -> String -> IO ()
 writeFileWithBackup f t = backUpFile f >> writeFile f t
 
 readFileStrictly :: FilePath -> IO String
-readFileStrictly f = readFile f >>= \s -> C.evaluate (length s) >> return s
+readFileStrictly f = readFile' f >>= \s -> C.evaluate (length s) >> return s
 
 -- | Back up this file with a (incrementing) numbered suffix, or give an error.
 backUpFile :: FilePath -> IO ()
